# OpenIBS: An Open-Source Package for Impulse-Based Substructuring

![coverage](https://gitlab.com/opentds/openibs/badges/main/coverage.svg)
[![OpenIbs Build Status](https://app.readthedocs.org/projects/openibs/badge/)](https://openibs.readthedocs.io/)

A collection of tools for the time domain analysis of mechanical systems.

## Installation

To install OpenIBS through pip, use the following command:

`pip install openibs`
